==> kadu_0.6.0.orig.tar.gz: kadu/modules/autoresponder/translations/autoresponder_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="3"/>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>Autoresponder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Autoanswer text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="15"/>
        <source>Only for the first time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Respond to conferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="22"/>
        <source>Choose status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="25"/>
        <source>Status invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Status busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="31"/>
        <source>Status available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <location filename="../autoresponder.cpp" line="85"/>
        <source>KADU AUTORESPONDER:</source>
        <translation>REPONDEUR KADU:</translation>
    </message>
    <message>
        <location filename="../autoresponder.cpp" line="132"/>
        <source>I am busy.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/autoresponder/translations/autoresponder_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoresponder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoanswer text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>REPONDEUR KADU:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
